<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:date="http://exslt.org/dates-and-times"
  xmlns:crypto="http://exslt.org/crypto"
  exclude-result-prefixes="xsl date crypto">

<!-- ## Basic transformation include ## -->
<xsl:include href="page2html.xsl" />

<!-- ## Custom template includes ## -->
<xsl:include href="common.xsl" />

<!--
  ### PAGE TEMPLATE ###

  Dependencies (used templates and variables not specified in this file):
    Templates:
    - navitems (consider: get the current active link via querying the page title or via param) 
    - header (may be renamed to common_html_head)
    - footer (common_page_footer)

    Variables: 
    - $baseurl
    - $common_title_prefix
    - $common_path
-->
            
<xsl:template name="main">
    <!-- TODO: Include proper DTD -->  
    <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html&gt;</xsl:text>

    <html lang="de" xml:lang="de">

        <!-- ## HTML HEAD ## -->
        <head>
            <!-- # Custom include #
            # Include the template containing
            # common header data like meta tags,
            # links and javascript-tags
            -->
            <xsl:call-template name="common_html_head" />

            <!-- # Basic include #
            # Add site-specific
            # includes
            -->
            <xsl:call-template name="head_include" />

            <title>
                &lt;&lt;&lt;/&gt;&gt; Chaos Computer Club Dresden | c3d2
                
                <!-- # Basic include # -->
                <xsl:call-template name="page_title" />
            </title>
        </head>
    
        <!-- ## HTML BODY ## -->
        <body>
            <div id="page">
                
                <!-- # PAGE HEAD # -->  
                <div id="head">
                    <!-- TODO: Include Logo-Artwork -->
                    <div id="title_logo">
                        <img src="images/c3d2_title.png" alt="C3D2" title="C3D2" /> 
                    </div>
                        <xsl:call-template name="navigation" />
                </div>

                <section id="content">

                <!-- Small hack to enable test for empty page title -->
                <xsl:variable name="title">
                    <xsl:call-template name="page_title" />
                </xsl:variable>
                <xsl:if test="$title != ''">
                    <h2>
                        <xsl:value-of select="$title" />
                    </h2>
                </xsl:if>

                <!-- # Basic include # -->
                <xsl:call-template name="page_body" />
            </section> 

            <!-- # PAGE FOOTER # -->
            <footer id="footer">
                <!-- ### Footer ### -->
                
                <ul>
                    <li>
                        <!-- Creative Commons License -->
                        <xsl:comment>
                            <xsl:text> Creative Commons License </xsl:text>
                        </xsl:comment>
                        <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.0/de/deed.de">
                            <img src="images/cc-somerights20.png"
                                width="88" height="31"
                                alt="Creative Commons License"
                                title="Creative Commons Attribution-ShareAlike 2.0 Germany License" />
                        </a>
                        <xsl:comment>
                            <xsl:text>
                                &lt;rdf:RDF xmlns="http://web.resource.org/cc/"
                                xmlns:dc="http://purl.org/dc/elements/1.1/"
                                xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"&gt;
                                &lt;Work rdf:about=""&gt;
                                &lt;dc:type rdf:resource="http://purl.org/dc/dcmitype/Interactive" /&gt;
                                &lt;license rdf:resource="http://creativecommons.org/licenses/by-sa/2.0/de/" /&gt;
                                &lt;/Work&gt;

                                &lt;License rdf:about="http://creativecommons.org/licenses/by-sa/2.0/de/"&gt;
                                &lt;permits rdf:resource="http://web.resource.org/cc/Reproduction" /&gt;
                                &lt;permits rdf:resource="http://web.resource.org/cc/Distribution" /&gt;
                                &lt;requires rdf:resource="http://web.resource.org/cc/Notice" /&gt;
                                &lt;requires rdf:resource="http://web.resource.org/cc/Attribution" /&gt;
                                &lt;permits rdf:resource="http://web.resource.org/cc/DerivativeWorks" /&gt;
                                &lt;requires rdf:resource="http://web.resource.org/cc/ShareAlike" /&gt;
                                &lt;/License&gt;
                                &lt;/rdf:RDF&gt;
                            </xsl:text>
                        </xsl:comment>
                    </li>
                    <li>
                        <a href="http://www.w3.org/html/logo/">
                            <img src="images/html5-badge-h-multimedia-semantics.png"
                                width="83" height="32"
                                alt="HTML5 Powered with Multimedia, and Semantics"
                                title="HTML5 Powered with Multimedia, and Semantics"/>
                        </a>
                    </li>
                </ul>

                <small class="hidden">
                    Cover, Concealment, Camouflage, Denial and Deception
                </small>
            </footer>
        </div> 
    </body> <!-- ## END OF HTML BODY ## --> 
</html>
</xsl:template>
</xsl:stylesheet>
