<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:date="http://exslt.org/dates-and-times"
  xmlns:content="http://purl.org/rss/1.0/modules/content/" 
  xmlns:atom="http://www.w3.org/2005/Atom"
  exclude-result-prefixes="xsl date">
  
  <xsl:output method="xml"
              version="1.0"
              encoding="utf-8"
              indent="yes"/>

  <!--
    # Starting point
    # ==============
    #
    # Matches root and calls the
    # main-Template defined within the
    # application-specific template.
  -->

  <xsl:template match="news">
      <xsl:element name="rss">
          <xsl:attribute name="version">2.0</xsl:attribute>
          <!--xsl:attribute name="xml:lang">de</xsl:attribute-->

          <!--  include domain-specific channel description -->  
          <xsl:call-template name="main" />
  </xsl:element>
  </xsl:template>

  <!-- 
    # Interface templates
    # ===================
    # 
    # To be used by the application-specific
    # xsl-template.
   -->
  <xsl:template name="rss_entries">
      <xsl:param name="prefix" />
          <!-- TODO: Insert "now": <pubDate><xsl:value-of select="news/item/@date"/></pubDate> -->
        <xsl:for-each select="newsfile">
          <xsl:sort select="date:seconds(document(.)/item/@date)" data-type="number" order="descending" />
          <xsl:variable name="newsfile" select="."/>
          <xsl:if test="(position() &lt;= $maxitems) and
                        starts-with(substring-after(substring-after($newsfile, '/'), '/'), $prefix)">
            
            <xsl:apply-templates select="document(.)/item">
              <xsl:with-param name="newsfile" select="$newsfile"/>
            </xsl:apply-templates>
            
          </xsl:if>
        </xsl:for-each>
  </xsl:template>

  <!--
   # Additional templates
   # ====================
   #
   -->

  <!--
   # Template to transform an item into an rss-entry.
   -->
  <xsl:template match="item">
    <xsl:param name="newsfile"/>
    <item>
      <xsl:variable name="href">
        <xsl:value-of select="$baseurl"/>
        <xsl:value-of select="substring-before(substring-after($newsfile, 'content/'), '.xml')"/>
        <xsl:text>.html</xsl:text>
      </xsl:variable>

      <title><xsl:value-of select="@title"/></title>
      <description>
	<xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
	<div xmlns="http://www.w3.org/1999/xhtml">
	  <xsl:apply-templates select="document($newsfile)/item/*"/>
	</div>
	<xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
      </description>
      <link><xsl:value-of select="$href"/></link>
      <!--
        TODO:
        Jemand mit iTunes (erhältlich für OSX und Windows)
        muss mal die itunes-extensions einbauen:
        http://www.apple.com/itunes/podcasts/techspecs.html
        -->
      <xsl:for-each select=".//*[name() = 'resource' or name() = 'alternative']">
        <xsl:variable name="resource_href">
          <xsl:call-template name="make-href">
            <xsl:with-param name="href" select="@url"/>
          </xsl:call-template>
        </xsl:variable>

        <enclosure url="{$resource_href}"
                   length="{@size}"
                   type="{@type}" />
      </xsl:for-each>

      <guid isPermaLink="true"><xsl:value-of select="$href"/></guid>

      <pubDate>
        <xsl:call-template name="date-to-rfc822">
          <xsl:with-param name="date" select="@date"/>
        </xsl:call-template>
      </pubDate>
      <content:encoded>
	<xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
	<div xmlns="http://www.w3.org/1999/xhtml">
	  <xsl:apply-templates select="document($newsfile)/item/*"/>
	</div>
	<xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
      </content:encoded>

      <xsl:variable name="flattr_link">
	<xsl:call-template name="make-flattr-link">
	  <xsl:with-param name="newsfile" select="$newsfile"/>
	</xsl:call-template>
      </xsl:variable>
      <xsl:if test="string-length($flattr_link) &gt; 0">
	<atom:link rel="payment" href="{$flattr_link}" type="text/html"/>
      </xsl:if>

      <xsl:copy-of select="resource/sc:chapters"
		   xmlns:sc="http://podlove.de/simple-chapters"/>

    </item>
  </xsl:template>

</xsl:stylesheet>
